@@ -264,7 +264,7 @@ def cmd_adapter_update(cmd_ctx, cpc_name, adapter_name, options):
 
     if not properties:
         cmd_ctx.spinner.stop()
-        click.echo("No properties specified for updating adapter {a}.".
+        click.echo("No properties specified for updating adapter '{a}'.".
                    format(a=adapter_name))
         return
 
@@ -275,10 +275,10 @@ def cmd_adapter_update(cmd_ctx, cpc_name, adapter_name, options):
 
     cmd_ctx.spinner.stop()
     if 'name' in properties and properties['name'] != adapter_name:
-        click.echo("Adapter {a} has been renamed to {an} and was updated.".
+        click.echo("Adapter '{a}' has been renamed to '{an}' and was updated.".
                    format(a=adapter_name, an=properties['name']))
     else:
-        click.echo("Adapter {a} has been updated.".format(a=adapter_name))
+        click.echo("Adapter '{a}' has been updated.".format(a=adapter_name))
 
 
 def cmd_adapter_create_hipersocket(cmd_ctx, cpc_name, options):
@@ -299,7 +299,7 @@ def cmd_adapter_create_hipersocket(cmd_ctx, cpc_name, options):
         raise click_exception(exc, cmd_ctx.error_format)
 
     cmd_ctx.spinner.stop()
-    click.echo("New HiperSockets adapter {a} has been created.".
+    click.echo("New HiperSockets adapter '{a}' has been created.".
                format(a=new_adapter.properties['name']))
 
 
@@ -315,5 +315,5 @@ def cmd_adapter_delete_hipersocket(cmd_ctx, cpc_name, adapter_name):
         raise click_exception(exc, cmd_ctx.error_format)
 
     cmd_ctx.spinner.stop()
-    click.echo("HiperSockets adapter {a} has been deleted.".
+    click.echo("HiperSockets adapter '{a}' has been deleted.".
                format(a=adapter_name))
