@@ -177,7 +177,7 @@ def cmd_port_update(cmd_ctx, cpc_name, adapter_name, port_name, options):
 
     if not properties:
         cmd_ctx.spinner.stop()
-        click.echo("No properties specified for updating port {p}.".
+        click.echo("No properties specified for updating port '{p}'.".
                    format(p=port_name))
         return
 
@@ -188,4 +188,4 @@ def cmd_port_update(cmd_ctx, cpc_name, adapter_name, port_name, options):
 
     cmd_ctx.spinner.stop()
     # Adapter ports cannot be renamed.
-    click.echo("Port {p} has been updated.".format(p=port_name))
+    click.echo("Port '{p}' has been updated.".format(p=port_name))
