@@ -247,7 +247,7 @@ def cmd_vfunction_create(cmd_ctx, cpc_name, partition_name, options):
     try:
         adapter = partition.manager.cpc.adapters.find(name=adapter_name)
     except zhmcclient.NotFound:
-        raise click_exception("Could not find adapter {a} in CPC {c}.".
+        raise click_exception("Could not find adapter '{a}' in CPC '{c}'.".
                               format(a=adapter_name, c=cpc_name),
                               cmd_ctx.error_format)
     properties['adapter-uri'] = adapter.uri
@@ -258,7 +258,7 @@ def cmd_vfunction_create(cmd_ctx, cpc_name, partition_name, options):
         raise click_exception(exc, cmd_ctx.error_format)
 
     cmd_ctx.spinner.stop()
-    click.echo("New virtual function {f} has been created.".
+    click.echo("New virtual function '{f}' has been created.".
                format(f=new_vfunction.properties['name']))
 
 
@@ -283,7 +283,7 @@ def cmd_vfunction_update(cmd_ctx, cpc_name, partition_name, vfunction_name,
             adapter = vfunction.manager.partition.manager.cpc.adapters.find(
                 name=adapter_name)
         except zhmcclient.NotFound:
-            raise click_exception("Could not find adapter {a} in CPC {c}.".
+            raise click_exception("Could not find adapter '{a}' in CPC '{c}'.".
                                   format(a=adapter_name, c=cpc_name),
                                   cmd_ctx.error_format)
         properties['adapter-uri'] = adapter.uri
@@ -301,10 +301,10 @@ def cmd_vfunction_update(cmd_ctx, cpc_name, partition_name, vfunction_name,
 
     cmd_ctx.spinner.stop()
     if 'name' in properties and properties['name'] != vfunction_name:
-        click.echo("Virtual function {f} has been renamed to {fn} and was "
+        click.echo("Virtual function '{f}' has been renamed to '{fn}' and was "
                    "updated.".format(f=vfunction_name, fn=properties['name']))
     else:
-        click.echo("Virtual function {f} has been updated.".
+        click.echo("Virtual function '{f}' has been updated.".
                    format(f=vfunction_name))
 
 
@@ -321,5 +321,5 @@ def cmd_vfunction_delete(cmd_ctx, cpc_name, partition_name, vfunction_name):
         raise click_exception(exc, cmd_ctx.error_format)
 
     cmd_ctx.spinner.stop()
-    click.echo("Virtual function {f} has been deleted.".
+    click.echo("Virtual function '{f}' has been deleted.".
                format(f=vfunction_name))
